@@ -4,6 +4,9 @@ URL_LOGIN = "http://127.0.0.1:8000/rest-auth/login/"
 URL_API_USERS = "http://127.0.0.1:8000/api/v1/users/"
 URL_API_INFOS = "http://127.0.0.1:8000/api/v1/infos/"
 URL_API_MICROSERVICE = "http://127.0.0.1:8000/api/v1/microservice/"
+URL_API_ERROS = 'http://127.0.0.1:8000/api/v1/error/'
+URL_API_CRITICALS = 'http://127.0.0.1:8000/api/v1/criticals/'
+URL_API_SUCCESS = 'http://127.0.0.1:8000/api/v1/success/'
 
 USERNAME_LOGIN_INTRANET = ""
 PASSWORD_LOGIN_INTRANET = ""
