@@ -1,7 +1,7 @@
 import logging
 
-import const
-from requests_cg import post_cg
+from portalcomponentscg import const
+from portalcomponentscg.requests_cg import post_cg
 
 logging.basicConfig(filename='logsPortal.log', level=logging.INFO,
                     format='%(levelname)s - %(message)s')
@@ -30,12 +30,35 @@ def LogsInfo(messages):
     pass
 
 
-def LogsErros(erros: []):
+def LogsErros(erros):
+
+    json = {
+        #"traceback": traceback,
+        "error_mesage": erros
+    }
+    post_cg(const.URL_API_ERROS, json)
 
     logging.error(erros)
+    pass
 
 
-def LogsCriticalErros(critical: []):
+def LogsCriticalErros(critical):
+
+    json = {
+            "critical": critical
+    }
+    post_cg(const.URL_API_CRITICALS, json)
 
     logging.warning(critical)
+    pass
 
+
+def LogsSuccess(success):
+
+    json = {
+        "success_mesage": success
+    }
+    post_cg(const.URL_API_SUCCESS, json)
+
+    logging.info(success)
+    pass
\ No newline at end of file
